@@ -217,7 +217,10 @@ class BottleClient:
 
     def get_hive_prediction_utility(self) -> dict:
         """Return prediction result data."""
-        return requests.get(f'{self.url}predictions/utility', headers=self.headers).json()
+        return requests.get(
+            f'{self.url}predictions/utility',
+            headers=self.headers,
+            json={'data': {'primitive_ids': [primitive['id'] for primitive in self.query_nodes]}}).json()
 
     def clear_wm(self, nodes: List = None) -> List:
         """Clear the Working Memory of the Genie."""
